@@ -34,10 +34,14 @@ def parse_general_result(sub, sub_rank=0):
 
     # Get title
     # title_div = sub.find('h3').find('a')
-    title_div = sub.find('div', {'class':'rc'})
-    if title_div:
-        parsed['title'] = title_div.find('h3').text
-        parsed['url'] = title_div.find('a')['href']
+    title_div1 = sub.find('div', {'class':'rc'})
+    title_div2 = sub.find('div', {'class':'yuRUbf'})
+    if title_div1:
+        parsed['title'] = title_div1.find('h3').text
+        parsed['url'] = title_div1.find('a')['href']
+    elif title_div2:
+        parsed['title'] = title_div2.find('h3').text
+        parsed['url'] = title_div2.find('a')['href']
 
     # Get citation
     cite = sub.find('cite')
