@@ -21,17 +21,33 @@ def parse_news_quote(sub, sub_rank=0):
     """
     parsed = {'type':'news_quotes', 'sub_rank':sub_rank}
     children = list(sub.children)
+
     if len(children) == 1: # Unfold nested div
         children = list(children[0].children)
     if len(children) == 2:
         quote, result = children
     else: # Remove dummy div in middle
         quote, _, result = children
-    title, meta = result.children
-    cite, timestamp = meta.children
-    parsed['text'] = quote.text
-    parsed['title'] = title.text
-    parsed['url'] = title['href']
-    parsed['cite'] = cite.text
-    parsed['timestamp'] = timestamp.text
+
+    # legacy parsing
+    if (len(list(result.children)) == 2):
+        title, meta = result.children
+        cite, timestamp = meta.children
+        parsed['title'] = title.text
+        parsed['url'] = title['href']
+        parsed['cite'] = cite.text
+        parsed['timestamp'] = timestamp.text
+    else:
+        all_result = list(result.children)
+        title = all_result[1]
+        cite  = all_result[0]
+        timestamp = all_result[2] # dates are no relative vs absolute
+        parsed['title'] = title.div.text
+        parsed['url'] = title['href']
+        parsed['cite'] = cite.span.text
+        parsed['timestamp'] = timestamp.div.text
+        
+    parsed['text'] = quote.text 
+    
     return parsed
+
