@@ -9,9 +9,8 @@ log = logger.Logger().start(__name__)
 
 import os
 import re
-import emoji
+# import emoji
 import atexit
-import brotli
 import requests
 import subprocess
 import tldextract
@@ -21,10 +20,9 @@ from bs4 import BeautifulSoup
 
 def load_html(fp, zipped=False):
     """Load html file, with option for brotli decompression"""
-    read_func = lambda i: brotli.decompress(i.read()) if zipped else i.read()
     read_type = 'rb' if zipped else 'r'
     with open(fp, read_type) as infile:
-        return read_func(infile)
+        return infile.read()
 
 def load_soup(fp, zipped=False):
     return make_soup(load_html(fp, zipped))
@@ -74,8 +72,8 @@ def parse_hashtags(text):
     hashtags = [re.sub(r"(\W+)$", "", h, flags = re.UNICODE) for h in hashtags]
     return list(set(hashtags))
 
-def parse_emojis(text):
-    return [emoji.demojize(e['emoji']) for e in emoji.emoji_lis(text)]
+# def parse_emojis(text):
+#     return [emoji.demojize(e['emoji']) for e in emoji.emoji_lis(text)]
 
 
 # URLs -------------------------------------------------------------------------
